use chrono::{DateTime, Utc};
use sqlx::Postgres;

pub struct Session {
    pub session_id: uuid::Uuid,
    pub user_id: uuid::Uuid,
    pub token: String,
    pub expires_at: DateTime<Utc>,
    pub created_at: DateTime<Utc>,
}

impl Session {
    pub async fn insert(
        &self,
        transaction: &mut sqlx::Transaction<'_, Postgres>,
    ) -> Result<(), sqlx::Error> {
        sqlx::query!(
            "
                INSERT INTO sessions (
                    session_id, user_id, token, expires_at, created_at
                )
                VALUES (
                    $1, $2, $3, $4, $5
                )
            ",
            &self.session_id,
            &self.user_id,
            &self.token,
            &self.expires_at,
            &self.created_at
        )
        .execute(&mut **transaction)
        .await?;

        Ok(())
    }
}
