use sqlx::{PgPool, Postgres};

#[derive(validator::Validate)]
pub struct User {
    pub user_id: uuid::Uuid,
    #[validate(email)]
    pub email: String,
    pub password: String,
    pub admin: bool,
}

impl User {
    pub async fn insert(
        transaction: &mut sqlx::Transaction<'_, Postgres>,
        email: &str,
        password: &str,
    ) -> Result<uuid::Uuid, sqlx::Error> {
        let user_id = uuid::Uuid::new_v4();

        sqlx::query!(
            "
                INSERT INTO users (
                    user_id, email, password, admin
                )
                VALUES (
                    $1, $2, $3, $4
                );
            ",
            &user_id,
            email,
            password,
            false
        )
        .execute(&mut **transaction)
        .await?;

        Ok(user_id)
    }

    pub async fn get_from_email(transaction: &PgPool, email: String) -> Result<Self, sqlx::Error> {
        let user = sqlx::query_as!(Self, "SELECT * FROM users WHERE email = $1", email)
            .fetch_one(transaction)
            .await?;

        Ok(user)
    }
}

#[derive(Debug)]
pub struct UserMember {
    user_id: uuid::Uuid,
    member_id: String,
}

impl UserMember {
    pub async fn insert_many(
        transaction: &mut sqlx::Transaction<'_, Postgres>,
        user_ids: &Vec<uuid::Uuid>,
        member_ids: &Vec<String>,
    ) -> Result<(), sqlx::Error> {
        sqlx::query!(
            "
                INSERT INTO users_members (
                    user_id, member_id
                )
                SELECT * FROM UNNEST($1::uuid[], $2::varchar[])
            ",
            &user_ids[..],
            &member_ids[..]
        )
        .execute(&mut **transaction)
        .await?;

        Ok(())
    }
}
